# boolean_comparison_operand_expression

# {'or' | '∨'} operations

# {'and' | '∧'} operations

# {'not' ~{{'in' | 'like'}}} operations

# NOT_OP

# arith_comparison_operand_expression

# contain_operator operations

# like_operator operations

# == | = | != | ≠ operations

# <= | >= | < | > | ≤ | ≥ operations

# Combine:({'search' 'for'}) operations

# SEARCH_FOR

# SEARCH

# FOR

# ident

# identifier

# integer

# operand_list

# LBRACK

# operand

# date_time

# date

# real number with scientific notation

# real number

# signed integer

# RBRACK

# nested_arith_comparison_operand

# <= | >= | < | > | ≤ | ≥

# == | = | != | ≠

# like_operator

# NOT_LIKE

# LIKE

# contain_operator

# NOT_IN

# NOT

# IN

# CONTAINS_ALL

# ALL

# CONTAINS_NONE

# NONE

# CONTAINS_ANY

# CONTAINS

# ANY

# ⊇ | ∈ | ∉

# nested_boolean_comparison_operand

# AND_OP

# AND

# OR_OP

# OR